import React from "react";
export interface GetStepOptions {
    routeTitle?: string;
}
export interface StepNavigationOptions {
    skipOnChangeHandler?: boolean;
}
interface InternalGoToStepOptions {
    resetMaxStepIndex?: boolean;
}
declare type GoToStepOptions = InternalGoToStepOptions & StepNavigationOptions;
export interface UseWizard {
    activeStepIndex: number;
    maxActivatedStepIndex: number;
    goToStep: (stepIndex: number, options?: StepNavigationOptions) => void;
    moveToStep: (stepIndex: number, options?: StepNavigationOptions) => void;
    resetToStep: (stepIndex: number, options?: StepNavigationOptions) => void;
    nextStep: () => void;
    previousStep: () => void;
    getStep: (options?: GetStepOptions) => Step;
}
export interface Step {
    index: number;
    isActive: boolean;
    hasBeenActive: boolean;
    nextStep: () => void;
    previousStep: () => void;
    resetToStep: () => void;
    moveToStep: () => void;
}
export declare type OnChangeHandler = (props: {
    newStepIndex: number;
    previousStepIndex: number;
    maxActivatedStepIndex: number;
}) => void;
declare type GoToStep = (stepIndex: number, options?: GoToStepOptions) => void;
export declare const WizardContext: React.Context<UseWizard | null>;
export interface UseWizardProps {
    initialStepIndex?: number;
    onChange?: OnChangeHandler;
}
export declare const useWizard: ({ initialStepIndex, onChange, }?: UseWizardProps) => {
    activeStepIndex: number;
    maxActivatedStepIndex: number;
    goToStep: GoToStep;
    nextStep: () => void;
    previousStep: () => void;
    getStep: (options?: GetStepOptions | undefined) => Step;
    moveToStep: (stepIndex: number, options?: StepNavigationOptions | undefined) => void;
    resetToStep: (stepIndex: number, options?: StepNavigationOptions | undefined) => void;
};
export interface UseWizardStepProps {
    routeTitle?: string;
}
export declare const useWizardStep: ({ routeTitle, }?: UseWizardStepProps) => Step;
export {};
